@@ -43,6 +43,10 @@ class Worksheet(object):
 	def num_columns(self):
 		return max(1, self._columns)
 	
+	def cell(self, name):
+		# convenience method
+		return self.range(name, name)
+	
 	def range(self, start, end):
 		# convenience method
 		return Range.Range(start, end, self)
@@ -58,6 +62,8 @@ class Worksheet(object):
 		self._merges.append(range)
 	
 	def get_cell_value(self, x, y):
+		if x not in self._cells:
+			self._cells[x] = {}
 		type = DataTypes.get_type(self._cells[x][y])
 		if type == DataTypes.FORMULA:
 			# remove the equals sign
@@ -68,6 +74,8 @@ class Worksheet(object):
 			return self._cells[x][y]
 	
 	def set_cell_value(self, x, y, value):
+		if x not in self._cells:
+			self._cells[x] = {}
 		self._cells[x][y] = value
 	
 	@property
@@ -80,10 +88,11 @@ class Worksheet(object):
 		for x, row in six.iteritems(self._cells):
 			row_data = []
 			for y, cell in six.iteritems(self._cells[x]):
-				if DataTypes.get_type(cell) == DataTypes.DATE:
-					row_data.append((Range.Range.coordinate_to_string((x, y)), datetime.strftime(cell, '%Y-%m-%dT%H:%M:%S'), DataTypes.get_type(cell)))
+				type = DataTypes.get_type(cell)
+				if type == DataTypes.DATE:
+					row_data.append((Range.Range.coordinate_to_string((x, y)), cell.strftime("%Y-%m-%dT%H:%M:%S.%f"), type))
 				else:
-					row_data.append((Range.Range.coordinate_to_string((x, y)), cell, DataTypes.get_type(cell)))
+					row_data.append((Range.Range.coordinate_to_string((x, y)), cell, type))
 			yield x, row_data
 
 	
